==> sale-3.1.2-71-sources.jar: Test.java <==
import com.af.plugins.AESUtil;
import com.af.plugins.calculate.StairpriceSettlement;
import org.apache.commons.codec.binary.Base64;
import org.bouncycastle.util.encoders.Base64Encoder;
import org.json.JSONArray;
import org.json.JSONObject;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.UnsupportedEncodingException;
import java.math.BigDecimal;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Calendar;
import java.util.Date;

public class Test {

    private static final Logger LOG = LoggerFactory.getLogger(Test.class);

    private static final String UTF_8 = "UTF-8";

    public static void main(String[] args) throws Exception{


       String str = "123@345";

        System.out.println(str.indexOf("&"));



    }

    public static boolean compareFormatDate(String dateStr1, String dateStr2,String formatStr) throws ParseException {
        SimpleDateFormat format = new SimpleDateFormat(formatStr);
        Date date1 = format.parse(dateStr1);
        Date date2 = format.parse(dateStr2);
        if (date1.before(date2)) {
            return false;
        } else if (date1.after(date2)) {
            return true;
        } else {
            return true;
        }
    }


    public static String dateDisp(Date before, Date after) {
        long time = after.getTime() - before.getTime();
        SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        return dateFormat.format(after) + "-" + dateFormat.format(before) + " 时间差:" + time;
    }


    public static String getDelayDate(String date, String type, String param)
            throws ParseException {
        //获取指定的时间
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        Date target = format.parse(date);
        Calendar cal = Calendar.getInstance();
        cal.setTime(target);
        //获取处理后的时间
        switch (type.toUpperCase()) {
            case "YEAR":
                cal.add(Calendar.YEAR, Integer.parseInt(param));
                break;
            case "MONTH":
                cal.add(Calendar.MONTH, Integer.parseInt(param));
                break;
            case "DAY":
                cal.add(Calendar.DAY_OF_MONTH, Integer.parseInt(param));
                break;
            default:
                throw new RuntimeException("不支持的日期类型！可选值(YEAR,MONTH,DATE)");
        }
        return format.format(cal.getTime());
    }

    public static String decodeData(String inputData) {
        try {
            if (null == inputData) {
                return null;
            }
            return new String(Base64.decodeBase64(inputData.getBytes(UTF_8)), UTF_8);
        } catch (UnsupportedEncodingException e) {
            LOG.error(inputData, e);
        }
        return null;
    }


    public static void jiami () {

        String str = "ji阿斯蒂芬as！@#……##@@撒对对对1234123【】、‘、、、。，";

        String result = AESUtil.encrypt(str, "jBKjDrnIhsGtjbeO");

        System.out.println(result);
    }

    public static void jiemi() {
        //        String temp = "WcGvK+9kGhLMByIj8MYi/S8kvL3f7yyNOvA4w2ssz9+sAXPS8C62CWirTHg2448smb9m6CtEvQ6KFwFvC5Ia+H9HuAs/nQpRGaMNsP2pVnFONzGmNYuTA8iVOs5uTEJu7JbxPfNkKyuIwKLJL1COZWCle5O9eDRFvG8QiMGoFztdcs1+r+p9HfXsAeZb9Yr/xpk+SkCJzzxImTyfQ5OgjQ1H1LfQtMgocPGRa4rb3zgbHAgSgfktSfDBuUhteUYUC3nrVTFTTT4alZHH5esk7A==";
        String temp = "qAuvk0STzEMu98/pX93vaIx8CXoVqz99tBJUwLuiCuk+xeDYu9rIWCBIxs/PJ78X";


        String res = AESUtil.decrypt(temp, "jBKjDrnIhsGtjbeO");

        System.out.println(res);
    }

}

==> sale-3.5.3-sources.jar: Test.java <==
import com.af.plugins.AESUtil;
import com.af.plugins.calculate.StairpriceSettlement;
import org.apache.commons.codec.binary.Base64;
import org.bouncycastle.util.encoders.Base64Encoder;
import org.json.JSONArray;
import org.json.JSONObject;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.io.UnsupportedEncodingException;
import java.math.BigDecimal;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.Calendar;
import java.util.Date;

public class Test {

    private static final Logger LOG = LoggerFactory.getLogger(Test.class);

    private static final String UTF_8 = "UTF-8";

    public static void main(String[] args) throws Exception{
//        String zz = "\\'";
//        System.out.println("qw+eq'w*eq".replaceAll("\\+|\\*|\\`|\\|\\-|\\$|\\#|\\!|\\@|\\%|\\&|\\~|\\^|\\'",""));
        System.out.println(now());
        System.out.println(getOne(now(),"day"));


    }
    public static String now(){
        DateTimeFormatter df = DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss");
        return df.format(LocalDateTime.now());
    }
    public static int getOne(String date,String key){
        LocalDateTime dateTime = LocalDateTime.parse(date, DateTimeFormatter.ofPattern("yyyy-MM-dd HH:mm:ss"));
        int res = -1;
        switch (key){
            case "year":
                res = dateTime.getYear();
                break;
            case "month":
                res = dateTime.getMonthValue();
                break;
            case "day":
                res = dateTime.getDayOfMonth();
                break;
            case "hour":
                res = dateTime.getHour();
                break;
            case "minute":
                res = dateTime.getMinute();
                break;
            case "second":
                res = dateTime.getSecond();
                break;
            default:
                res = -1;
        }
        return res;
    }

    public static boolean compareFormatDate(String dateStr1, String dateStr2,String formatStr) throws ParseException {
        SimpleDateFormat format = new SimpleDateFormat(formatStr);
        Date date1 = format.parse(dateStr1);
        Date date2 = format.parse(dateStr2);
        if (date1.before(date2)) {
            return false;
        } else if (date1.after(date2)) {
            return true;
        } else {
            return true;
        }
    }


    public static String dateDisp(Date before, Date after) {
        long time = after.getTime() - before.getTime();
        SimpleDateFormat dateFormat = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        return dateFormat.format(after) + "-" + dateFormat.format(before) + " 时间差:" + time;
    }


    public static String getDelayDate(String date, String type, String param)
            throws ParseException {
        //获取指定的时间
        SimpleDateFormat format = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
        Date target = format.parse(date);
        Calendar cal = Calendar.getInstance();
        cal.setTime(target);
        //获取处理后的时间
        switch (type.toUpperCase()) {
            case "YEAR":
                cal.add(Calendar.YEAR, Integer.parseInt(param));
                break;
            case "MONTH":
                cal.add(Calendar.MONTH, Integer.parseInt(param));
                break;
            case "DAY":
                cal.add(Calendar.DAY_OF_MONTH, Integer.parseInt(param));
                break;
            default:
                throw new RuntimeException("不支持的日期类型！可选值(YEAR,MONTH,DATE)");
        }
        return format.format(cal.getTime());
    }

    public static String decodeData(String inputData) {
        try {
            if (null == inputData) {
                return null;
            }
            return new String(Base64.decodeBase64(inputData.getBytes(UTF_8)), UTF_8);
        } catch (UnsupportedEncodingException e) {
            LOG.error(inputData, e);
        }
        return null;
    }


    public static void jiami () {

        String str = "ji阿斯蒂芬as！@#……##@@撒对对对1234123【】、‘、、、。，";

        String result = AESUtil.encrypt(str, "jBKjDrnIhsGtjbeO");

        System.out.println(result);
    }

    public static void jiemi() {
        //        String temp = "WcGvK+9kGhLMByIj8MYi/S8kvL3f7yyNOvA4w2ssz9+sAXPS8C62CWirTHg2448smb9m6CtEvQ6KFwFvC5Ia+H9HuAs/nQpRGaMNsP2pVnFONzGmNYuTA8iVOs5uTEJu7JbxPfNkKyuIwKLJL1COZWCle5O9eDRFvG8QiMGoFztdcs1+r+p9HfXsAeZb9Yr/xpk+SkCJzzxImTyfQ5OgjQ1H1LfQtMgocPGRa4rb3zgbHAgSgfktSfDBuUhteUYUC3nrVTFTTT4alZHH5esk7A==";
        String temp = "qAuvk0STzEMu98/pX93vaIx8CXoVqz99tBJUwLuiCuk+xeDYu9rIWCBIxs/PJ78X";


        String res = AESUtil.decrypt(temp, "jBKjDrnIhsGtjbeO");

        System.out.println(res);
    }


}
